#!/bin/make
# -- file containing the global settings for the Gameboy C environment
#
# naming convention for variables:
#  - globally visible names are upper-case and underscore-separated
#  - local names are lower-case, camel-cased

SHELL:=/bin/sh
.SUFFIXES:

#---------------------------
#- target root directories -
#---------------------------

# the root of the file system (for convenience)
ROOT_DIR:=C:

#-- the root of the complete installation target directories
installationRootDir:=$(ROOT_DIR)/temp/gameboy

#-- the root directory of C include files
TARGET_INCLUDE_ROOT_DIR:=$(installationRootDir)/include

#-- the root directory of C src files
TARGET_SOURCE_ROOT_DIR:=$(installationRootDir)/lib-src

#-- the root directory of object files
TARGET_OBJECT_ROOT_DIR:=$(installationRootDir)/objects

#--------------------
#- support programs -
#--------------------

programDirectory:=$(ROOT_DIR)/Programme
binDirectory:=$(programDirectory)/Cygwin/bin

#-- the path name of the copy program (CP)
CP_PROGRAM:=$(binDirectory)/cp.exe

#-- the path name of the GAWK program
GAWK_PROGRAM:=$(binDirectory)/gawk.exe

#-- the path name of the directory creation program (MKDIR)
MKDIR_PROGRAM:=$(binDirectory)/mkdir.exe

#-- the path name of the file movement program (MV)
MV_PROGRAM:=$(binDirectory)/mv.exe

#-- the path name of the file deletion program (RM)
RM_PROGRAM:=$(binDirectory)/rm.exe -f

#-- the directory of the specific development tools
currentFilePath:=$(strip $(dir $(lastword $(MAKEFILE_LIST))))
TOOLS_DIR:=$(currentFilePath)tools

#-- the directory of the SDCC compiler
SDCC_PATH:=$(programDirectory)/Programmierung/Gameboy/gbdk

#---------------------------
#- configuration variables -
#---------------------------

# -- this variable selects either English or German as the game
# -- language compiled into the executable
TARGET_LANGUAGE_IS_ENGLISH:=true

# -- tells whether assembly list files should be kept in objects
# -- directory
KEEP_LIST_FILES:=false

#--------------------
#- library settings -
#--------------------

#-- the library paths and files for SDCC
SDCC_LIBRARIES:=-k$(TARGET_OBJECT_ROOT_DIR)/gbextended -lgbext.lib \
                -k$(TARGET_OBJECT_ROOT_DIR)/gb -lgb.lib \
                -k${TARGET_OBJECT_ROOT_DIR}/gbz80 \
                -lgbz80.lib

#-- the main object file for SDCC containing the base runtime system
#-- (like crt.o in some appropriate path)
SDCC_STANDARD_OBJECTS:=$(TARGET_OBJECT_ROOT_DIR)/gb/crt0.o
